==> disspy-0.5.2.tar.gz: disspy-0.5.2/disspy/user.py <==
"""
MIT License

Copyright (c) 2022 itttgg

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

__all__: tuple = (
    "DisUser"
)


class DisUser:
    def __init__(self, data, token):
        self.id: int = int(data["id"])
        self._t = token

        self.username = data["username"]
        self.discriminator = data["discriminator"]
        self.fullname = f"{self.username}#{self.discriminator}"

        try:
            self.isbot: bool = data["bot"]
        except KeyError:
            pass
        try:
            self.isverified: bool = data["verified"]
        except KeyError:
            pass
        try:
            self.email: bool = data["email"]  # May be ""
        except KeyError:
            pass

        self.flags: int = int(data["public_flags"])

==> disspy-0.5.3.3.tar.gz: disspy-0.5.3.3/disspy/user.py <==
"""
MIT License

Copyright (c) 2022 itttgg

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

__all__: tuple = (
    "DisUser"
)


class DisUser:
    def __init__(self, data, token):
        self.id: int = int(data["id"])
        self._t = token

        self.username = data["username"]
        self.discriminator = data["discriminator"]
        self.fullname = f"{self.username}#{self.discriminator}"
        self.is_bot = None
        self.is_verified = None
        self.email = None

        if "bot" in data:
            self.is_bot: bool = data["bot"]

        if "verified" in data:
            self.is_verified: bool = data["verified"]

        if "email" in data:
            self.email: bool = data["email"]  # May be ""

        self.flags: int = int(data["public_flags"])
